@@ -264,7 +264,7 @@ test -x $tzdata_prog && test -d $tzdata_dir && tzdata_entry=$(entry \
     "set_time-and_date.sh &" \
     $"Set Date and Time")
 
-ceni_prog=/usr/bin/ceni
+ceni_prog=/usr/sbin/ceni
 test -x $ceni_prog && ceni_entry=$(entry \
     $ICONS/ceni.png \
     "desktop-defaults-run -t sudo ceni &" \
